|Build Status|

findbugs2junit
==============

Simple tool to convert a findbugs xml file to junit xml for reporting to
Jenkins.

.. |Build Status| image:: https://travis-ci.org/hughsaunders/findbugs2junit.svg?branch=master
   :target: https://travis-ci.org/hughsaunders/findbugs2junit
